@@ -4,8 +4,8 @@
  *
  * @author Open Dynamics / Philipp Kiszka <info@o-dyn.de>
  * @name datei
- * @version 0.5.5
- * @package Cffollabtive
+ * @version 0.7
+ * @package Collabtive
  * @link http://www.o-dyn.de
  * @license http://opensource.org/licenses/gpl-license.php GNU General Public License v3 or later
  */
@@ -19,6 +19,7 @@ class datei
     {
         $this->mylog = new mylog;
     }
+    
     // FOLDER METHODS
     /**
      * Create a new folder
@@ -32,6 +33,7 @@ class datei
     {
         $project = (int) $project;
         $folder = mysql_real_escape_string($folder);
+        $folderOrig = $folder;
         $desc = mysql_real_escape_string($desc);
         if(!empty($visible))
         {
@@ -59,7 +61,8 @@ class datei
             {
                 if (mkdir($makefolder, 0777, true))
                 {
-                    // folder created return true
+                    // folder created
+					$this->mylog->add($folderOrig, 'folder', 1, $project);
                     return true;
                 }
             }
@@ -102,11 +105,14 @@ class datei
             }
         }
         $del = mysql_query("DELETE FROM projectfolders WHERE ID = $id");
-        // remove directory
-        $foldstr = CL_ROOT . "/files/" . CL_CONFIG . "/$project/" . $folder["name"] . "/";
-        delete_directory($foldstr);
-
-        return true;
+        if ($del)
+		{
+			// remove directory
+			$foldstr = CL_ROOT . "/files/" . CL_CONFIG . "/$project/" . $folder["name"] . "/";
+			delete_directory($foldstr);
+			$this->mylog->add($folder["name"], 'folder', 3, $project);
+			return true;
+		}
     }
 
     /**
@@ -211,6 +217,7 @@ class datei
             return false;
         }
     }
+    
     // FILE METHODS
     /**
      * Upload a file
@@ -262,7 +269,7 @@ class datei
         $erweiterung = $teilnamen[$workteile];
         $subname = "";
         // if its a php file, treat it as plaintext so its not executed when opened in the browser.
-        if (stristr($typ, "php"))
+        if (stristr($erweiterung, "php"))
         {
             $erweiterung = "txt";
             $typ = "text/plain";
@@ -273,7 +280,7 @@ class datei
             $subname .= $teilnamen[$i];
         }
 
-        $randval = mt_rand(1, 9999999);
+        $randval = mt_rand(1, 99999);
         // only allow a-z , 0-9 in filenames, substitute other chars with _
         $subname = str_replace("ä", "ae" , $subname);
         $subname = str_replace("ö", "oe" , $subname);
@@ -308,11 +315,11 @@ class datei
                     $fid = $this->add_file($name, $desc, $project, 0, "$tags", $datei_final2, "$typ", $title, $folder, $visstr);
 					if(!empty($title))
 					{
-						$this->mylog->add($title, 'datei', 1, $project);
+						$this->mylog->add($title, 'file', 1, $project);
                     }
 					else
 					{
-						$this->mylog->add($name, 'datei', 1, $project);
+						$this->mylog->add($name, 'file', 1, $project);
 					}
 					return $fid;
                 }
@@ -358,7 +365,7 @@ class datei
         $sql = mysql_query("UPDATE files SET `title` = '$title', `desc` = '$desc', `tags` = '$tags' WHERE id = $id");
         if ($sql)
         {
-            $this->mylog->add($title, 'datei' , 2, $project);
+            $this->mylog->add($title, 'file' , 2, $project);
             return true;
         }
         else
@@ -398,7 +405,11 @@ class datei
             {
                 if (unlink($delfile))
                 {
-                    $this->mylog->add($ftitle, 'datei' , 3, $project);
+					if ($ftitle != "") {
+						$this->mylog->add($ftitle, 'file', 3, $project);
+					} else {
+						$this->mylog->add($fname, 'file', 3, $project);
+					}
                     return true;
                 }
                 else
